<?php

namespace Focus\Salesmanager\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Focus\Salesmanager\Http\Requests\SalesmanagerRequest;
use Focus\Salesmanager\Interfaces\SalesmanagerRepositoryInterface;
use Focus\Salesmanager\Models\Salesmanager;

/**
 * Resource controller class for salesmanager.
 */
class SalesmanagerResourceController extends BaseController
{

    /**
     * Initialize salesmanager resource controller.
     *
     * @param type SalesmanagerRepositoryInterface $salesmanager
     *
     * @return null
     */
    public function __construct(SalesmanagerRepositoryInterface $salesmanager)
    {
        parent::__construct();
        $this->repository = $salesmanager;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Focus\Salesmanager\Repositories\Criteria\SalesmanagerResourceCriteria::class);
    }

    /**
     * Display a list of salesmanager.
     *
     * @return Response
     */
    public function index(SalesmanagerRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Focus\Salesmanager\Repositories\Presenter\SalesmanagerPresenter::class)
                ->$function();
        }

        $salesmanagers = $this->repository->paginate();

        return $this->response->title(trans('salesmanager::salesmanager.names'))
            ->view('salesmanager::salesmanager.index', true)
            ->data(compact('salesmanagers'))
            ->output();
    }

    /**
     * Display salesmanager.
     *
     * @param Request $request
     * @param Model   $salesmanager
     *
     * @return Response
     */
    public function show(SalesmanagerRequest $request, Salesmanager $salesmanager)
    {

        if ($salesmanager->exists) {
            $view = 'salesmanager::salesmanager.show';
        } else {
            $view = 'salesmanager::salesmanager.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('salesmanager::salesmanager.name'))
            ->data(compact('salesmanager'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new salesmanager.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(SalesmanagerRequest $request)
    {

        $salesmanager = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('salesmanager::salesmanager.name')) 
            ->view('salesmanager::salesmanager.create', true) 
            ->data(compact('salesmanager'))
            ->output();
    }

    /**
     * Create new salesmanager.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(SalesmanagerRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $salesmanager                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('salesmanager::salesmanager.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('salesmanager/salesmanager/' . $salesmanager->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/salesmanager/salesmanager'))
                ->redirect();
        }

    }

    /**
     * Show salesmanager for editing.
     *
     * @param Request $request
     * @param Model   $salesmanager
     *
     * @return Response
     */
    public function edit(SalesmanagerRequest $request, Salesmanager $salesmanager)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('salesmanager::salesmanager.name'))
            ->view('salesmanager::salesmanager.edit', true)
            ->data(compact('salesmanager'))
            ->output();
    }

    /**
     * Update the salesmanager.
     *
     * @param Request $request
     * @param Model   $salesmanager
     *
     * @return Response
     */
    public function update(SalesmanagerRequest $request, Salesmanager $salesmanager)
    {
        try {
            $attributes = $request->all();

            $salesmanager->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('salesmanager::salesmanager.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('salesmanager/salesmanager/' . $salesmanager->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('salesmanager/salesmanager/' . $salesmanager->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the salesmanager.
     *
     * @param Model   $salesmanager
     *
     * @return Response
     */
    public function destroy(SalesmanagerRequest $request, Salesmanager $salesmanager)
    {
        try {

            $salesmanager->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('salesmanager::salesmanager.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('salesmanager/salesmanager/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('salesmanager/salesmanager/' . $salesmanager->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple salesmanager.
     *
     * @param Model   $salesmanager
     *
     * @return Response
     */
    public function delete(SalesmanagerRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('salesmanager::salesmanager.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('salesmanager/salesmanager'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/salesmanager/salesmanager'))
                ->redirect();
        }

    }

    /**
     * Restore deleted salesmanagers.
     *
     * @param Model   $salesmanager
     *
     * @return Response
     */
    public function restore(SalesmanagerRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('salesmanager::salesmanager.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/salesmanager/salesmanager'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/salesmanager/salesmanager/'))
                ->redirect();
        }

    }

}
